@@ -24,7 +24,15 @@ def cal_563_mos(degFile):
     :return: 无参考的MOS,语音电平，信噪比，噪声电平
     """
     p563 = p563Struct()
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/p563.dll')
+
+    import platform
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/p563.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/p563.dylib')
+
     #buf = create_string_buffer(degFile.encode('gbk'), len(degFile))
     buf = c_char_p(bytes(degFile.encode('utf-8')))
     mydll.NR_MOS(buf,byref(p563))
