@@ -50,8 +50,6 @@ def get_data_of_ctypes_(inWaveFile=None,int2float=False):
     ref = ref.astype(np.float64)
     if int2float:
         ref = ref/32768
-
-
     datastruct = emxArray_real_T()
 
     datastruct.pdata = (c_double * refframeCount)(*ref)
@@ -59,6 +57,19 @@ def get_data_of_ctypes_(inWaveFile=None,int2float=False):
     wavf.close()
     return  datastruct,refsamplerate,refframeCount
 
+def get_data_of_ctypes_from_datablock(inData=None,datalen=96000,int2float=False):
+
+    ref = np.frombuffer(inData,dtype=np.int16)
+
+    ref = ref.astype(np.float64)
+    if int2float:
+        ref = ref/32768
+    datastruct = emxArray_real_T()
+    datastruct.pdata = (c_double * datalen)(*ref)
+    datastruct.psize = (c_int * 1)(*[datalen])
+
+    return  datastruct
+
 def get_none_data_of_ctypes_(dataLength=0):
 
     data =  np.array([0.0 for _ in range(dataLength)])
@@ -73,6 +84,8 @@ def get_none_data_of_ctypes_(dataLength=0):
     outStruct.canFreeData = 1
     return outStruct
 
+
+
 def write_ctypes_data_2_file_(outFile,outStruct,refsamplerate):
     outf = wave.open(outFile, 'wb')
     outf.setnchannels(1)
